<?php

namespace Drupal\llom\Form;

/**
 * @file
 * Llom configuration form.
 *
 * Date: 23 Feb 2024 19:11:24
 * File: LlomAdminForm.php
 * Author: stefano.
 */

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\language\ConfigurableLanguageManagerInterface;
use Drupal\system\Entity\Menu;

/**
 * Defines a form that configures forms module settings.
 */
class LlomAdminForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'llom_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'llom.admin_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $menus_tree = Menu::loadMultiple();

    $menu_option = [];

    foreach ($menus_tree as $menu) {
      $menu_option[$menu->id()] = $menu->label();
    }

    $config = $this->config('llom.admin_settings');
    $form['menu'] = [
      '#type' => 'checkboxes',
      '#options' => $menu_option,
      '#title' => $this->t('Menu'),
      '#description' => $this->t('Select the menus. Please, before check if the menu supports sub-menu.'),
      '#default_value' => ($config->get('llom_menu') ?? []),
    ];

    $language_manager = \Drupal::languageManager();

    if ($language_manager instanceof ConfigurableLanguageManagerInterface) {
      $info = $language_manager->getDefinedLanguageTypesInfo();
      $configurable_types = $language_manager->getLanguageTypes();
      foreach ($configurable_types as $type) {
        $ltype_option[$type] = t('@type', ['@type' => $info[$type]['name']]);
      }
    }

    $form['ltype'] = [
      '#type' => 'checkboxes',
      '#options' => $ltype_option,
      '#title' => $this->t('Language type'),
      '#description' => $this->t('The definite types text for languages.'),
      '#default_value' => ($config->get('llom_ltype') ?? []),
    ];

    $form['weight'] = [
      '#type' => 'weight',
      '#title' => $this->t('Weight'),
      '#description' => $this->t('Menu item weight of <em>current</em> language.'),
      '#delta' => 100,
      '#default_value' => (int) $config->get('llom_weight') ?? 50,
    ];

    /**
     * @var Drupal\Core\Language\LanguageManager
     */
    $language_current = \Drupal::service('language_manager')->getCurrentLanguage();

    $form['code'] = [
      '#type' => 'select',
      '#options' => ['full' => t('Full'), 'short' => t('Short')],
      '#title' => $this->t('Text format'),
      '#description' => $this->t('If the menu item text has a <i>full</i> (@full) or <i>short</i> (@short) format.',
      [
        '@full' => $language_current->getName(),
        '@short' => $language_current->getId(),
      ]),
      '#default_value' => ($config->get('llom_code') ?? 'full'),
    ];

    $pub_files = \Drupal::service('file_url_generator')
      ->generateAbsoluteString('public://');

    $form['flag'] = [
      '#type' => 'radios',
      '#title' => t('Flags'),
      '#options' => [
        'never' => t('Never'),
        'before' => t('Before'),
        'after' => t('After'),
        'notext' => t('Only'),
      ],
      '#default_value' => ($config->get('llom_flag') ?? 'never'),
      '#description' => t('Put your images inside of %path as <i>language ISO code</i>.png (like %short.png for @full). <i>No check will done if image/language esists.</i>',
      [
        '%path' => $pub_files,
        '%short' => $language_current->getId(),
        '@full' => $language_current->getName(),
      ]),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('llom.admin_settings')
      ->set('llom_menu', $form_state->getValue('menu'))
      ->set('llom_weight', $form_state->getValue('weight'))
      ->set('llom_code', $form_state->getValue('code'))
      ->set('llom_ltype', $form_state->getValue('ltype'))
      ->set('llom_flag', $form_state->getValue('flag'))
      ->save();
    parent::submitForm($form, $form_state);

    // Rebuild the menu.
    //
    // SC 11 Mar 2024 17:00:38 stefano.
    //
    \Drupal::service('plugin.manager.menu.link')->rebuild();
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

}
